===
API
===

Here's the public API for Henson.

Application
===========

.. autoclass:: henson.base.Application
   :members:

Command Line Interface
======================

.. automodule:: henson.cli
   :members:

Configuration
=============

.. autoclass:: henson.config.Config
   :members:

Exceptions
==========

.. automodule:: henson.exceptions
   :members:

Extensions
==========

.. autoclass:: henson.extensions.Extension
   :members:
